#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_scalpg_dump
----------------------------------

Tests for `scalpg_dump` module.
"""


import unittest


class TestScalpg_dump(unittest.TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_000_something(self):
        pass
